@@ -43,6 +43,8 @@
 #define MIN_VIEW_PERCENT 0.1
 #define RSTTO_LINE_WIDTH 1.0
 
+#define ERROR_UNDETERMINED "Undetermined error"
+
 enum
 {
     PROP_0,
@@ -606,6 +608,8 @@ rstto_image_viewer_finalize (GObject *object)
 {
     RsttoImageViewer *viewer = RSTTO_IMAGE_VIEWER (object);
 
+    if (viewer->priv->transaction && viewer->priv->transaction->loader_closed_id != 0)
+        REMOVE_SOURCE (viewer->priv->transaction->loader_closed_id);
     if (viewer->priv->settings)
     {
         g_object_unref (viewer->priv->settings);
@@ -641,6 +645,11 @@ rstto_image_viewer_finalize (GObject *object)
         g_object_unref (viewer->priv->file);
         viewer->priv->file = NULL;
     }
+    if (viewer->priv->error)
+    {
+        g_error_free (viewer->priv->error);
+        viewer->priv->error = NULL;
+    }
 
     G_OBJECT_CLASS (rstto_image_viewer_parent_class)->finalize (object);
 }
@@ -1391,7 +1400,6 @@ rstto_image_viewer_load_image (RsttoImageViewer *viewer, RsttoFile *file, gdoubl
     transaction->file = file;
     transaction->viewer = viewer;
     transaction->scale = scale;
-    transaction->loader_closed_id = 0;
 
     if (viewer->priv->limit_quality)
     {
@@ -1430,8 +1438,6 @@ rstto_image_viewer_transaction_free (gpointer data)
     {
         tr->viewer->priv->transaction = NULL;
     }
-    if (tr->loader_closed_id != 0)
-        REMOVE_SOURCE (tr->loader_closed_id);
     if (tr->error)
     {
         g_error_free (tr->error);
@@ -1735,14 +1741,23 @@ cb_rstto_image_loader_closed_idle (gpointer data)
 {
     RsttoImageViewerTransaction *transaction = data;
     RsttoImageViewer *viewer = transaction->viewer;
+    GdkPixbuf *pixbuf;
     GtkWidget *widget = GTK_WIDGET (viewer);
 
     if (viewer->priv->transaction == transaction)
     {
+        pixbuf = gdk_pixbuf_loader_get_pixbuf (transaction->loader);
+
+        /* cover any case where no pixbuf is available and no error is set:
+         * see e.g. https://gitlab.gnome.org/GNOME/gdk-pixbuf/-/issues/204 */
+        if (transaction->error == NULL && pixbuf == NULL)
+            g_set_error (&transaction->error, GDK_PIXBUF_ERROR,
+                         GDK_PIXBUF_ERROR_FAILED, ERROR_UNDETERMINED);
+
         if (transaction->error == NULL || (
                 g_error_matches (transaction->error, GDK_PIXBUF_ERROR,
                                  GDK_PIXBUF_ERROR_CORRUPT_IMAGE)
-                && gdk_pixbuf_loader_get_pixbuf (transaction->loader) != NULL
+                && pixbuf != NULL
             ))
         {
             gtk_widget_set_tooltip_text (widget, NULL);
@@ -2118,7 +2133,7 @@ cb_rstto_bgcolor_changed (GObject *settings, GParamSpec *pspec, gpointer user_da
     cairo_region_t *region;
     cairo_status_t status;
     GtkAllocation alloc;
-    const gchar *message = "Undetermined error";
+    const gchar *message = ERROR_UNDETERMINED;
 
     /* do not redraw the image */
     gtk_widget_get_allocation (user_data, &alloc);
